@@ -11,9 +11,13 @@ class TestAttachedFilesCleanerValidator:
     def setup_method(self):
         """Set up test fixtures."""
         self.validator = AttachedFilesCleanerValidator()
-        self.test_spreadsheet_url = "https://docs.google.com/spreadsheets/d/test_id/edit"
+        self.test_spreadsheet_url = (
+            "https://docs.google.com/spreadsheets/d/test_id/edit"
+        )
         self.test_excel_path = "/tmp/test.xlsx"
-        self.test_auth_credentials = {"encoded_creds": "fake_base64_encoded_service_account"}
+        self.test_auth_credentials = {
+            "encoded_creds": "fake_base64_encoded_service_account"
+        }
 
     def test_validator_initialization(self):
         """Test that the validator is properly initialized."""
@@ -29,33 +33,28 @@ class TestAttachedFilesCleanerValidator:
             ("Clean the attached report following these directions.", 1),
             ("Update the attached spreadsheet with new data.", 1),
             ("Check the attached document for details.", 1),
-            
             # With descriptive words
             ("Can you clean the data in the attached Google Sheet?", 1),
             ("Review the attached Excel file carefully.", 1),
             ("Process the attached Document List spreadsheet.", 1),
-            
             # Preposition patterns
             ("In the attached sheet, please highlight rows.", 1),
             ("From the attached report, extract the data.", 1),
             ("With the attached document, create a summary.", 1),
-            
             # "Please find attached" patterns
             ("Please find attached the quarterly report.", 1),
             # Note: "Find attached documentation" doesn't match our patterns - only "Please find attached"
-            
             # "that I have attached" patterns
             ("Please clean the data in the Google Sheet that I have attached.", 1),
-            
             # "data attached in" patterns
             ("I need help cleaning the data attached in the Google Sheet.", 1),
-            
             # "Attached is" sentence starters
             ("Attached is our new spreadsheet that tracks inventory.", 1),
-            
             # Complex compound names
-            ("The attached HR Food Desert Analysis spreadsheet combines multiple sources.", 1),
-            
+            (
+                "The attached HR Food Desert Analysis spreadsheet combines multiple sources.",
+                1,
+            ),
             # No mentions
             ("This prompt has no file references.", 0),
             ("Please update the data in column A.", 0),
@@ -75,56 +74,82 @@ class TestAttachedFilesCleanerValidator:
 
         for text in non_file_cases:
             mentions = self.validator._find_attachment_mentions(text)
-            assert len(mentions) == 0, f"Should have skipped non-file attachment: {text}"
+            assert len(mentions) == 0, (
+                f"Should have skipped non-file attachment: {text}"
+            )
 
     def test_clean_attachment_mentions_simple_removal(self):
         """Test simple attachment mention cleaning."""
         test_cases = [
             # Basic determiner patterns
             ("Please clean the attached report.", "Please clean the report."),
-            ("Review the attached spreadsheet carefully.", "Review the spreadsheet carefully."),
-            ("Update the attached document with changes.", "Update the document with changes."),
-            
+            (
+                "Review the attached spreadsheet carefully.",
+                "Review the spreadsheet carefully.",
+            ),
+            (
+                "Update the attached document with changes.",
+                "Update the document with changes.",
+            ),
             # Preposition patterns
-            ("In the attached sheet, highlight the rows.", "In the sheet, highlight the rows."),
-            ("From the attached report, extract data.", "From the report, extract data."),
-            
+            (
+                "In the attached sheet, highlight the rows.",
+                "In the sheet, highlight the rows.",
+            ),
+            (
+                "From the attached report, extract data.",
+                "From the report, extract data.",
+            ),
             # "Please find attached" → "Please review"
-            ("Please find attached the 2025 Performance Files.", "Please review the 2025 Performance Files."),
-            
+            (
+                "Please find attached the 2025 Performance Files.",
+                "Please review the 2025 Performance Files.",
+            ),
             # "that I have attached" → "provided"
-            ("Clean the Google Sheet that I have attached.", "Clean the Google Sheet provided."),
-            
+            (
+                "Clean the Google Sheet that I have attached.",
+                "Clean the Google Sheet provided.",
+            ),
             # "data attached in" → "data in"
-            ("Clean the data attached in the Google Sheet.", "Clean the data in the Google Sheet."),
-            
+            (
+                "Clean the data attached in the Google Sheet.",
+                "Clean the data in the Google Sheet.",
+            ),
             # "Attached is" → "Here is"
             ("Attached is our new spreadsheet.", "Here is our new spreadsheet."),
-            
             # Complex compound names (note: pattern replacement may change capitalization)
-            ("The attached HR Food Desert Analysis spreadsheet", "the HR Food Desert Analysis spreadsheet"),
+            (
+                "The attached HR Food Desert Analysis spreadsheet",
+                "the HR Food Desert Analysis spreadsheet",
+            ),
         ]
 
         for original, expected in test_cases:
             mentions = self.validator._find_attachment_mentions(original)
             if mentions:
-                cleaned, note = self.validator._clean_attachment_mentions(original, mentions)
-                first_line = cleaned.split('\n')[0]
-                assert first_line == expected, f"Expected: '{expected}', Got: '{first_line}'"
+                cleaned, note = self.validator._clean_attachment_mentions(
+                    original, mentions
+                )
+                first_line = cleaned.split("\n")[0]
+                assert first_line == expected, (
+                    f"Expected: '{expected}', Got: '{first_line}'"
+                )
                 assert "[Editor" in note
 
     def test_clean_attachment_mentions_multiple(self):
         """Test cleaning text with multiple attachment mentions."""
-        original = "Review the attached report and check the data in the attached spreadsheet."
+        original = (
+            "Review the attached report and check the data in the attached spreadsheet."
+        )
         mentions = self.validator._find_attachment_mentions(original)
-        
+
         cleaned, note = self.validator._clean_attachment_mentions(original, mentions)
-        first_line = cleaned.split('\n')[0]
-        
+        first_line = cleaned.split("\n")[0]
+
         # Should remove both mentions
         assert "attached" not in first_line.lower()
         assert "Review the report and check the data in the spreadsheet." == first_line
-        
+
         # Should indicate multiple removals
         assert len(mentions) >= 1  # Should find at least one mention
         assert "[Editor" in note
@@ -133,13 +158,13 @@ class TestAttachedFilesCleanerValidator:
         """Test cleaning text with no attachment mentions."""
         original = "This is a normal prompt without file references."
         mentions = []
-        
+
         cleaned, note = self.validator._clean_attachment_mentions(original, mentions)
-        
+
         assert cleaned == original
         assert note == ""
 
-    def test_validate_flag_mode_with_issues(self):
+    def test_validate_flag_mode_with_flags(self):
         """Test validation in flag mode with attachment mentions."""
         # Mock sheet data with attachment mentions
         test_data = [
@@ -149,8 +174,10 @@ class TestAttachedFilesCleanerValidator:
             ["3", "This prompt has no file references.", "Clean task"],
         ]
 
-        with patch.object(self.validator, '_get_all_sheet_data') as mock_get_data:
-            with patch.object(self.validator, '_get_spreadsheet') as mock_get_spreadsheet:
+        with patch.object(self.validator, "_get_all_sheet_data") as mock_get_data:
+            with patch.object(
+                self.validator, "_get_spreadsheet"
+            ) as mock_get_spreadsheet:
                 mock_get_data.return_value = (test_data, "Sheet1")
                 mock_spreadsheet = MagicMock()
                 mock_get_spreadsheet.return_value = mock_spreadsheet
@@ -158,21 +185,21 @@ class TestAttachedFilesCleanerValidator:
                 result = self.validator.validate(
                     spreadsheet_source=self.test_spreadsheet_url,
                     mode="flag",
-                    auth_credentials=self.test_auth_credentials
+                    auth_credentials=self.test_auth_credentials,
                 )
 
-                # Should find 2 issues (rows 1 and 2)
+                # Should find 2 flags (rows 1 and 2)
                 assert result["fixes_applied"] == 0
-                assert result["issues_found"] == 2
+                assert result["flags_found"] == 2
                 assert len(result["errors"]) == 0
-                
-                # Should have details about the issues
-                assert "issues" in result["details"]
-                assert len(result["details"]["issues"]) == 2
-                assert result["details"]["issues"][0]["cell"] == "Sheet1!B1"
-                assert result["details"]["issues"][1]["cell"] == "Sheet1!B2"
 
-    def test_validate_fix_mode_with_issues(self):
+                # Should have details about the flags
+                assert "flags" in result["details"]
+                assert len(result["details"]["flags"]) == 2
+                assert result["details"]["flags"][0]["cell"] == "Sheet1!B1"
+                assert result["details"]["flags"][1]["cell"] == "Sheet1!B2"
+
+    def test_validate_fix_mode_with_flags(self):
         """Test validation in fix mode with attachment mentions."""
         # Mock sheet data with attachment mentions
         test_data = [
@@ -182,9 +209,11 @@ class TestAttachedFilesCleanerValidator:
             ["3", "This prompt has no file references.", "Clean task"],
         ]
 
-        with patch.object(self.validator, '_get_all_sheet_data') as mock_get_data:
-            with patch.object(self.validator, '_update_sheet_data') as mock_update_data:
-                with patch.object(self.validator, '_get_spreadsheet') as mock_get_spreadsheet:
+        with patch.object(self.validator, "_get_all_sheet_data") as mock_get_data:
+            with patch.object(self.validator, "_update_sheet_data") as mock_update_data:
+                with patch.object(
+                    self.validator, "_get_spreadsheet"
+                ) as mock_get_spreadsheet:
                     mock_get_data.return_value = (test_data, "Sheet1")
                     mock_spreadsheet = MagicMock()
                     mock_get_spreadsheet.return_value = mock_spreadsheet
@@ -192,12 +221,12 @@ class TestAttachedFilesCleanerValidator:
                     result = self.validator.validate(
                         spreadsheet_source=self.test_spreadsheet_url,
                         mode="fix",
-                        auth_credentials=self.test_auth_credentials
+                        auth_credentials=self.test_auth_credentials,
                     )
 
-                    # Should fix 2 issues
+                    # Should fix 2 flags
                     assert result["fixes_applied"] == 2
-                    assert result["issues_found"] == 0
+                    assert result["flags_found"] == 0
                     assert len(result["errors"]) == 0
 
                     # Should have called update method
@@ -210,7 +239,7 @@ class TestAttachedFilesCleanerValidator:
                     assert result["details"]["fixes"][0]["cell"] == "Sheet1!B1"
                     assert result["details"]["fixes"][1]["cell"] == "Sheet1!B2"
 
-    def test_validate_no_issues(self):
+    def test_validate_no_flags(self):
         """Test validation when no attachment mentions are found."""
         # Mock sheet data without attachment mentions
         test_data = [
@@ -220,8 +249,10 @@ class TestAttachedFilesCleanerValidator:
             ["3", "Update the formatting in the document.", "Clean task"],
         ]
 
-        with patch.object(self.validator, '_get_all_sheet_data') as mock_get_data:
-            with patch.object(self.validator, '_get_spreadsheet') as mock_get_spreadsheet:
+        with patch.object(self.validator, "_get_all_sheet_data") as mock_get_data:
+            with patch.object(
+                self.validator, "_get_spreadsheet"
+            ) as mock_get_spreadsheet:
                 mock_get_data.return_value = (test_data, "Sheet1")
                 mock_spreadsheet = MagicMock()
                 mock_get_spreadsheet.return_value = mock_spreadsheet
@@ -229,19 +260,21 @@ class TestAttachedFilesCleanerValidator:
                 result = self.validator.validate(
                     spreadsheet_source=self.test_spreadsheet_url,
                     mode="flag",
-                    auth_credentials=self.test_auth_credentials
+                    auth_credentials=self.test_auth_credentials,
                 )
 
-                # Should find no issues
+                # Should find no flags
                 assert result["fixes_applied"] == 0
-                assert result["issues_found"] == 0
+                assert result["flags_found"] == 0
                 assert len(result["errors"]) == 0
                 assert "No attached file mentions found" in result["automated_log"]
 
     def test_validate_empty_sheet(self):
         """Test validation when sheet is empty."""
-        with patch.object(self.validator, '_get_all_sheet_data') as mock_get_data:
-            with patch.object(self.validator, '_get_spreadsheet') as mock_get_spreadsheet:
+        with patch.object(self.validator, "_get_all_sheet_data") as mock_get_data:
+            with patch.object(
+                self.validator, "_get_spreadsheet"
+            ) as mock_get_spreadsheet:
                 mock_get_data.return_value = ([], "Sheet1")
                 mock_spreadsheet = MagicMock()
                 mock_get_spreadsheet.return_value = mock_spreadsheet
@@ -249,12 +282,12 @@ class TestAttachedFilesCleanerValidator:
                 result = self.validator.validate(
                     spreadsheet_source=self.test_spreadsheet_url,
                     mode="flag",
-                    auth_credentials=self.test_auth_credentials
+                    auth_credentials=self.test_auth_credentials,
                 )
 
                 # Should handle empty sheet gracefully
                 assert result["fixes_applied"] == 0
-                assert result["issues_found"] == 0
+                assert result["flags_found"] == 0
                 assert len(result["errors"]) == 1
                 assert "Sheet is empty" in result["errors"][0]
 
@@ -266,8 +299,10 @@ class TestAttachedFilesCleanerValidator:
             ["1", "Test task", "data"],
         ]
 
-        with patch.object(self.validator, '_get_all_sheet_data') as mock_get_data:
-            with patch.object(self.validator, '_get_spreadsheet') as mock_get_spreadsheet:
+        with patch.object(self.validator, "_get_all_sheet_data") as mock_get_data:
+            with patch.object(
+                self.validator, "_get_spreadsheet"
+            ) as mock_get_spreadsheet:
                 mock_get_data.return_value = (test_data, "Sheet1")
                 mock_spreadsheet = MagicMock()
                 mock_get_spreadsheet.return_value = mock_spreadsheet
@@ -276,12 +311,12 @@ class TestAttachedFilesCleanerValidator:
                     spreadsheet_source=self.test_spreadsheet_url,
                     mode="flag",
                     auth_credentials=self.test_auth_credentials,
-                    target_column="prompt"
+                    target_column="prompt",
                 )
 
                 # Should handle missing column gracefully
                 assert result["fixes_applied"] == 0
-                assert result["issues_found"] == 0
+                assert result["flags_found"] == 0
                 assert len(result["errors"]) == 0
                 assert "not found" in result["automated_log"]
 
@@ -294,8 +329,10 @@ class TestAttachedFilesCleanerValidator:
             ["2", "Clean the data without file references.", "Another task"],
         ]
 
-        with patch.object(self.validator, '_get_all_sheet_data') as mock_get_data:
-            with patch.object(self.validator, '_get_spreadsheet') as mock_get_spreadsheet:
+        with patch.object(self.validator, "_get_all_sheet_data") as mock_get_data:
+            with patch.object(
+                self.validator, "_get_spreadsheet"
+            ) as mock_get_spreadsheet:
                 mock_get_data.return_value = (test_data, "Sheet1")
                 mock_spreadsheet = MagicMock()
                 mock_get_spreadsheet.return_value = mock_spreadsheet
@@ -304,27 +341,27 @@ class TestAttachedFilesCleanerValidator:
                     spreadsheet_source=self.test_spreadsheet_url,
                     mode="flag",
                     auth_credentials=self.test_auth_credentials,
-                    target_column="instructions"
+                    target_column="instructions",
                 )
 
                 # Should find 1 issue in the instructions column
-                assert result["issues_found"] == 1
+                assert result["flags_found"] == 1
                 assert len(result["errors"]) == 0
 
     def test_validate_handles_exceptions(self):
         """Test that validation handles unexpected exceptions gracefully."""
-        with patch.object(self.validator, '_get_spreadsheet') as mock_get_spreadsheet:
+        with patch.object(self.validator, "_get_spreadsheet") as mock_get_spreadsheet:
             mock_get_spreadsheet.side_effect = Exception("Test error")
 
             result = self.validator.validate(
                 spreadsheet_source=self.test_spreadsheet_url,
                 mode="flag",
-                auth_credentials=self.test_auth_credentials
+                auth_credentials=self.test_auth_credentials,
             )
 
             # Should handle exception gracefully
             assert result["fixes_applied"] == 0
-            assert result["issues_found"] == 0
+            assert result["flags_found"] == 0
             assert len(result["errors"]) == 1
             assert "Unexpected error" in result["errors"][0]
             assert "Validation failed" in result["automated_log"]
@@ -333,16 +370,24 @@ class TestAttachedFilesCleanerValidator:
         """Test the _should_skip_mention function directly."""
         # Test cases that should be skipped (only "attached to each other" is currently skipped)
         skip_cases = [
-            ("The parts are attached to each other in the assembly.", 15, 26),  # "attached to"
+            (
+                "The parts are attached to each other in the assembly.",
+                15,
+                26,
+            ),  # "attached to"
         ]
 
         for text, start, end in skip_cases:
             should_skip = self.validator._should_skip_mention(text, start, end)
             assert should_skip, f"Should skip: {text[start:end]}"
-        
+
         # Test cases that should NOT be skipped
         dont_skip_cases = [
-            ("These wires are attached to the circuit board.", 16, 27),  # Different usage, not skipped currently
+            (
+                "These wires are attached to the circuit board.",
+                16,
+                27,
+            ),  # Different usage, not skipped currently
             ("Please review the attached document.", 18, 35),  # File attachment
             ("Clean the attached spreadsheet.", 10, 28),  # File attachment
         ]
@@ -353,14 +398,16 @@ class TestAttachedFilesCleanerValidator:
 
     def test_automated_log_messages(self):
         """Test that appropriate automated log messages are generated."""
-        # Test with issues found in flag mode
+        # Test with flags found in flag mode
         test_data = [
             ["prompt"],
             ["Review the attached file."],
         ]
 
-        with patch.object(self.validator, '_get_all_sheet_data') as mock_get_data:
-            with patch.object(self.validator, '_get_spreadsheet') as mock_get_spreadsheet:
+        with patch.object(self.validator, "_get_all_sheet_data") as mock_get_data:
+            with patch.object(
+                self.validator, "_get_spreadsheet"
+            ) as mock_get_spreadsheet:
                 mock_get_data.return_value = (test_data, "Sheet1")
                 mock_spreadsheet = MagicMock()
                 mock_get_spreadsheet.return_value = mock_spreadsheet
@@ -368,26 +415,34 @@ class TestAttachedFilesCleanerValidator:
                 result = self.validator.validate(
                     spreadsheet_source=self.test_spreadsheet_url,
                     mode="flag",
-                    auth_credentials=self.test_auth_credentials
+                    auth_credentials=self.test_auth_credentials,
                 )
 
-                assert "Found 1 prompts with attached file mentions" in result["automated_log"]
+                assert (
+                    "Found 1 prompts with attached file mentions"
+                    in result["automated_log"]
+                )
 
         # Test with fixes applied
-        with patch.object(self.validator, '_get_all_sheet_data') as mock_get_data:
-            with patch.object(self.validator, '_update_sheet_data'):
-                with patch.object(self.validator, '_get_spreadsheet') as mock_get_spreadsheet:
+        with patch.object(self.validator, "_get_all_sheet_data") as mock_get_data:
+            with patch.object(self.validator, "_update_sheet_data"):
+                with patch.object(
+                    self.validator, "_get_spreadsheet"
+                ) as mock_get_spreadsheet:
                     mock_get_data.return_value = (test_data, "Sheet1")
                     mock_spreadsheet = MagicMock()
                     mock_get_spreadsheet.return_value = mock_spreadsheet
-                    
+
                     result = self.validator.validate(
                         spreadsheet_source=self.test_spreadsheet_url,
                         mode="fix",
-                        auth_credentials=self.test_auth_credentials
+                        auth_credentials=self.test_auth_credentials,
                     )
 
-                    assert "Cleaned 1 prompts with attached file mentions" in result["automated_log"]
+                    assert (
+                        "Cleaned 1 prompts with attached file mentions"
+                        in result["automated_log"]
+                    )
 
 
 class TestAttachedFilesCleanerIntegration:
@@ -400,44 +455,60 @@ class TestAttachedFilesCleanerIntegration:
     def test_real_world_examples(self):
         """Test with real-world examples from the CSV data."""
         real_examples = [
-            ("Can you please clean the data in the attached Google Sheet for me?", 
-             "Can you please clean the data in the Google Sheet for me?"),
-            ("Clean the attached report following these directions:",
-             "Clean the report following these directions:"),
-            ("I need to clean up the data in the attached Google Sheet so that I can accurately assess the models.",
-             "I need to clean up the data in the Google Sheet so that I can accurately assess the models."),
-            ("Please find attached the 2025 Performance Personnel Files.",
-             "Please review the 2025 Performance Personnel Files."),
-            ("In the attached sheet, please highlight rows where the price is high.",
-             "In the sheet, please highlight rows where the price is high."),
-            ("The attached spreadsheet has a list of customer contacts.",
-             "The spreadsheet has a list of customer contacts."),
+            (
+                "Can you please clean the data in the attached Google Sheet for me?",
+                "Can you please clean the data in the Google Sheet for me?",
+            ),
+            (
+                "Clean the attached report following these directions:",
+                "Clean the report following these directions:",
+            ),
+            (
+                "I need to clean up the data in the attached Google Sheet so that I can accurately assess the models.",
+                "I need to clean up the data in the Google Sheet so that I can accurately assess the models.",
+            ),
+            (
+                "Please find attached the 2025 Performance Personnel Files.",
+                "Please review the 2025 Performance Personnel Files.",
+            ),
+            (
+                "In the attached sheet, please highlight rows where the price is high.",
+                "In the sheet, please highlight rows where the price is high.",
+            ),
+            (
+                "The attached spreadsheet has a list of customer contacts.",
+                "The spreadsheet has a list of customer contacts.",
+            ),
         ]
 
         for original, expected in real_examples:
             mentions = self.validator._find_attachment_mentions(original)
             # Should find at least one mention in each real example
             assert len(mentions) >= 1, f"Failed to detect mentions in: {original}"
-            
+
             # Should be able to clean each example
-            cleaned, note = self.validator._clean_attachment_mentions(original, mentions)
-            first_line = cleaned.split('\n')[0]
-            assert first_line == expected, f"Expected: '{expected}', Got: '{first_line}'"
+            cleaned, note = self.validator._clean_attachment_mentions(
+                original, mentions
+            )
+            first_line = cleaned.split("\n")[0]
+            assert first_line == expected, (
+                f"Expected: '{expected}', Got: '{first_line}'"
+            )
             assert "[Editor" in note
 
     def test_comprehensive_workflow(self):
         """Test the complete workflow from detection to cleaning."""
         test_prompt = "Please clean the data in the attached Google Sheet and review the attached documentation for guidelines."
-        
+
         # Step 1: Detect mentions
         mentions = self.validator._find_attachment_mentions(test_prompt)
         assert len(mentions) >= 1  # Should find at least one mention
-        
+
         # Step 2: Clean the text
         cleaned, note = self.validator._clean_attachment_mentions(test_prompt, mentions)
-        
+
         # Step 3: Verify results
-        cleaned.split('\n')[0]
+        cleaned.split("\n")[0]
         # Note: Our current patterns may not catch all mentions in one pass
         # That's expected behavior - we're focusing on file attachments, not all uses of "attached"
         assert len(mentions) >= 1  # Should find at least one mention
@@ -448,23 +519,24 @@ class TestAttachedFilesCleanerIntegration:
         edge_cases = [
             # Empty text
             ("", 0),
-            
             # Single word
             ("attached", 0),  # No file type, should not match
-            
             # Multiple same mentions - our patterns may match this as one long pattern
-            ("The attached file and the attached document", 1),  # Compound pattern may match as one
-            
+            (
+                "The attached file and the attached document",
+                1,
+            ),  # Compound pattern may match as one
             # Non-file uses (should be skipped)
             ("The parts are attached to each other", 0),
-            
             # Mixed file and non-file (may detect both patterns)
             ("Clean the attached report. The wires are attached to the board.", 2),
         ]
 
         for text, expected_count in edge_cases:
             mentions = self.validator._find_attachment_mentions(text)
-            assert len(mentions) == expected_count, f"Expected {expected_count} mentions in: '{text}', got {len(mentions)}"
+            assert len(mentions) == expected_count, (
+                f"Expected {expected_count} mentions in: '{text}', got {len(mentions)}"
+            )
 
     def test_pattern_coverage_completeness(self):
         """Test that all our enhanced patterns are working."""
@@ -472,33 +544,24 @@ class TestAttachedFilesCleanerIntegration:
             # Rule 1: Determiner + attached + file type
             ("the attached spreadsheet", 1),
             ("this attached document", 1),
-            
             # Rule 2a: Please find attached
             ("Please find attached the files", 1),
-            
             # Rule 2b: See attached
             ("Please see attached for details", 1),
-            
             # Rule 3: Preposition + attached + file type
             ("in the attached Google Sheet", 1),
             ("from the attached report", 1),
-            
             # Rule 4: Bare "the attached"
             ("Refer to the attached.", 1),
-            
             # Rule 6: Specific file types
             ("attached spreadsheet", 1),
             ("attached document", 1),
-            
             # Rule 10: "that I have attached"
             ("the sheet that I have attached", 1),
-            
             # Rule 11: "data attached in"
             ("data attached in the sheet", 1),
-            
             # Rule 12: "Attached is"
             ("Attached is our spreadsheet", 1),
-            
             # Rule 13: Complex compound names
             ("The attached HR Analysis spreadsheet", 1),
         ]
