@@ -15,7 +15,7 @@ from urarovite.utils.generic_spreadsheet import (
     convert_excel_to_google_sheets,
     convert_spreadsheet_format,
     _copy_google_sheets_to_google_sheets,
-    _copy_excel_to_excel
+    _copy_excel_to_excel,
 )
 from urarovite.core.exceptions import ValidationError
 from .fixtures import BaseTestCase
@@ -41,13 +41,13 @@ class TestConvertGoogleSheetsToExcel(BaseTestCase):
             source_sheets=["Sheet1", "Sheet2"],
             sheet_data={
                 "Sheet1": [["A1", "B1"], ["A2", "B2"]],
-                "Sheet2": [["C1", "D1"], ["C2", "D2"]]
-            }
-        ) as mocks:
+                "Sheet2": [["C1", "D1"], ["C2", "D2"]],
+            },
+        ):
             result = convert_google_sheets_to_excel(
                 google_sheets_url="https://docs.google.com/spreadsheets/d/test123/edit",
                 excel_file_path=self.temp_dir / "output.xlsx",
-                auth_credentials={"auth_secret": self.encoded_creds}
+                auth_credentials={"auth_secret": self.encoded_creds},
             )
 
             # Verify result
@@ -65,14 +65,14 @@ class TestConvertGoogleSheetsToExcel(BaseTestCase):
             sheet_data={
                 "Sheet1": [["A1", "B1"]],
                 "Sheet2": [["C1", "D1"]],
-                "Sheet3": [["E1", "F1"]]
-            }
-        ) as mocks:
+                "Sheet3": [["E1", "F1"]],
+            },
+        ):
             result = convert_google_sheets_to_excel(
                 google_sheets_url="https://docs.google.com/spreadsheets/d/test123/edit",
                 excel_file_path=self.temp_dir / "output.xlsx",
                 auth_credentials={"auth_secret": self.encoded_creds},
-                sheet_names=["Sheet1", "Sheet3"]
+                sheet_names=["Sheet1", "Sheet3"],
             )
 
             assert result["success"] is True
@@ -89,13 +89,13 @@ class TestConvertGoogleSheetsToExcel(BaseTestCase):
             # Make one sheet fail
             mocks["source"].get_sheet_data.side_effect = [
                 Mock(values=[["A1", "B1"]], sheet_name="Sheet1"),
-                Exception("Failed to get Sheet2 data")
+                Exception("Failed to get Sheet2 data"),
             ]
 
             result = convert_google_sheets_to_excel(
                 google_sheets_url="https://docs.google.com/spreadsheets/d/test123/edit",
                 excel_file_path=self.temp_dir / "output.xlsx",
-                auth_credentials={"auth_secret": self.encoded_creds}
+                auth_credentials={"auth_secret": self.encoded_creds},
             )
 
             assert result["success"] is True  # Partial success
@@ -106,11 +106,11 @@ class TestConvertGoogleSheetsToExcel(BaseTestCase):
 
     def test_file_extension_handling(self):
         """Test that .xlsx extension is added if missing."""
-        with mock_manager.spreadsheet_scenario() as mocks:
+        with mock_manager.spreadsheet_scenario():
             result = convert_google_sheets_to_excel(
                 google_sheets_url="https://docs.google.com/spreadsheets/d/test123/edit",
                 excel_file_path=self.temp_dir / "output",  # No extension
-                auth_credentials={"auth_secret": self.encoded_creds}
+                auth_credentials={"auth_secret": self.encoded_creds},
             )
 
             assert result["success"] is True
@@ -136,25 +136,26 @@ class TestConvertExcelToGoogleSheets(BaseTestCase):
         test_file = self.temp_dir / "input.xlsx"
         try:
             from openpyxl import Workbook
+
             wb = Workbook()
             ws = wb.active
-            ws['A1'] = "A1"
-            ws['B1'] = "B1"
-            ws['A2'] = "A2"
-            ws['B2'] = "B2"
+            ws["A1"] = "A1"
+            ws["B1"] = "B1"
+            ws["A2"] = "A2"
+            ws["B2"] = "B2"
             wb.save(str(test_file))
         except ImportError:
             # Create a dummy file if openpyxl not available
             test_file.write_text("dummy excel content")
-        
+
         with mock_manager.spreadsheet_scenario(
             source_sheets=["Sheet1"],
-            sheet_data={"Sheet1": [["A1", "B1"], ["A2", "B2"]]}
-        ) as mocks:
+            sheet_data={"Sheet1": [["A1", "B1"], ["A2", "B2"]]},
+        ):
             result = convert_excel_to_google_sheets(
                 excel_file_path=self.temp_dir / "input.xlsx",
                 google_sheets_url="https://docs.google.com/spreadsheets/d/target123/edit",
-                auth_credentials={"auth_secret": self.encoded_creds}
+                auth_credentials={"auth_secret": self.encoded_creds},
             )
 
             assert result["success"] is True
@@ -168,26 +169,27 @@ class TestConvertExcelToGoogleSheets(BaseTestCase):
         test_file = self.temp_dir / "input.xlsx"
         try:
             from openpyxl import Workbook
+
             wb = Workbook()
             ws1 = wb.active
             ws1.title = "NewSheet1"
-            ws1['A1'] = "Data1"
+            ws1["A1"] = "Data1"
             ws2 = wb.create_sheet("NewSheet2")
-            ws2['A1'] = "Data2"
+            ws2["A1"] = "Data2"
             wb.save(str(test_file))
         except ImportError:
             # Create a dummy file if openpyxl not available
             test_file.write_text("dummy excel content")
-        
+
         with mock_manager.spreadsheet_scenario(
             source_sheets=["NewSheet1", "NewSheet2"],
-            target_sheets=["Sheet"]  # Target has different sheets
+            target_sheets=["Sheet"],  # Target has different sheets
         ) as mocks:
             result = convert_excel_to_google_sheets(
                 excel_file_path=self.temp_dir / "input.xlsx",
                 google_sheets_url="https://docs.google.com/spreadsheets/d/target123/edit",
                 auth_credentials={"auth_secret": self.encoded_creds},
-                create_new_sheets=True
+                create_new_sheets=True,
             )
 
             assert result["success"] is True
@@ -212,7 +214,7 @@ class TestConvertSpreadsheetFormat(BaseTestCase):
         """Test auto-detection of Google Sheets to Excel conversion."""
         # Mock the underlying conversion functions to return success
         with patch(
-            'urarovite.utils.enhanced_conversion.convert_with_full_formatting'
+            "urarovite.utils.enhanced_conversion.convert_with_full_formatting"
         ) as mock_enhanced_convert:
             mock_enhanced_convert.return_value = {
                 "success": True,
@@ -220,13 +222,13 @@ class TestConvertSpreadsheetFormat(BaseTestCase):
                 "converted_sheets": ["Sheet1"],
                 "formula_stats": {"total_formulas": 0},
                 "formatting_stats": {"cells_with_formatting": 0},
-                "error": None
+                "error": None,
             }
 
             result = convert_spreadsheet_format(
                 source="https://docs.google.com/spreadsheets/d/source123/edit",
                 target=str(self.temp_dir / "output.xlsx"),
-                auth_credentials={"auth_secret": self.encoded_creds}
+                auth_credentials={"auth_secret": self.encoded_creds},
             )
 
             assert result["success"] is True
@@ -239,7 +241,7 @@ class TestConvertSpreadsheetFormat(BaseTestCase):
         test_file.touch()
 
         with patch(
-            'urarovite.utils.enhanced_conversion.convert_with_full_formatting'
+            "urarovite.utils.enhanced_conversion.convert_with_full_formatting"
         ) as mock_enhanced_convert:
             mock_enhanced_convert.return_value = {
                 "success": True,
@@ -247,13 +249,13 @@ class TestConvertSpreadsheetFormat(BaseTestCase):
                 "converted_sheets": ["Sheet1"],
                 "formula_stats": {"total_formulas": 0},
                 "formatting_stats": {"cells_with_formatting": 0},
-                "error": None
+                "error": None,
             }
 
             result = convert_spreadsheet_format(
                 source=str(test_file),
                 target="https://docs.google.com/spreadsheets/d/target123/edit",
-                auth_credentials={"auth_secret": self.encoded_creds}
+                auth_credentials={"auth_secret": self.encoded_creds},
             )
 
             assert result["success"] is True
@@ -262,7 +264,7 @@ class TestConvertSpreadsheetFormat(BaseTestCase):
     def test_google_sheets_to_google_sheets_detection(self):
         """Test auto-detection of Google Sheets to Google Sheets copy."""
         with patch(
-            'urarovite.utils.enhanced_conversion.convert_with_full_formatting'
+            "urarovite.utils.enhanced_conversion.convert_with_full_formatting"
         ) as mock_enhanced_convert:
             mock_enhanced_convert.return_value = {
                 "success": True,
@@ -270,13 +272,13 @@ class TestConvertSpreadsheetFormat(BaseTestCase):
                 "converted_sheets": ["Sheet1"],
                 "formula_stats": {"total_formulas": 0},
                 "formatting_stats": {"cells_with_formatting": 0},
-                "error": None
+                "error": None,
             }
 
             result = convert_spreadsheet_format(
                 source="https://docs.google.com/spreadsheets/d/source123/edit",
                 target="https://docs.google.com/spreadsheets/d/target123/edit",
-                auth_credentials={"auth_secret": self.encoded_creds}
+                auth_credentials={"auth_secret": self.encoded_creds},
             )
 
             assert result["success"] is True
@@ -290,7 +292,7 @@ class TestConvertSpreadsheetFormat(BaseTestCase):
         input_file.touch()
 
         with patch(
-            'urarovite.utils.enhanced_conversion.convert_with_full_formatting'
+            "urarovite.utils.enhanced_conversion.convert_with_full_formatting"
         ) as mock_enhanced_convert:
             mock_enhanced_convert.return_value = {
                 "success": True,
@@ -298,13 +300,13 @@ class TestConvertSpreadsheetFormat(BaseTestCase):
                 "converted_sheets": ["Sheet1"],
                 "formula_stats": {"total_formulas": 0},
                 "formatting_stats": {"cells_with_formatting": 0},
-                "error": None
+                "error": None,
             }
 
             result = convert_spreadsheet_format(
                 source=str(input_file),
                 target=str(output_file),
-                auth_credentials={"auth_secret": self.encoded_creds}
+                auth_credentials={"auth_secret": self.encoded_creds},
             )
 
             assert result["success"] is True
@@ -326,11 +328,11 @@ class TestCopyFunctions(BaseTestCase):
 
     def test_copy_google_sheets_to_google_sheets(self):
         """Test copying between Google Sheets."""
-        with mock_manager.spreadsheet_scenario() as mocks:
+        with mock_manager.spreadsheet_scenario():
             result = _copy_google_sheets_to_google_sheets(
                 source_url="https://docs.google.com/spreadsheets/d/source123/edit",
                 target_url="https://docs.google.com/spreadsheets/d/target123/edit",
-                auth_credentials={"auth_secret": self.encoded_creds}
+                auth_credentials={"auth_secret": self.encoded_creds},
             )
 
             assert result["success"] is True
@@ -338,10 +340,10 @@ class TestCopyFunctions(BaseTestCase):
 
     def test_copy_excel_to_excel(self):
         """Test copying between Excel files."""
-        with mock_manager.spreadsheet_scenario() as mocks:
+        with mock_manager.spreadsheet_scenario():
             result = _copy_excel_to_excel(
                 source_path=str(self.temp_dir / "source.xlsx"),
-                target_path=str(self.temp_dir / "target.xlsx")
+                target_path=str(self.temp_dir / "target.xlsx"),
             )
 
             assert result["success"] is True
@@ -349,10 +351,10 @@ class TestCopyFunctions(BaseTestCase):
 
     def test_copy_excel_extension_handling(self):
         """Test Excel copy with extension handling."""
-        with mock_manager.spreadsheet_scenario() as mocks:
+        with mock_manager.spreadsheet_scenario():
             result = _copy_excel_to_excel(
                 source_path=str(self.temp_dir / "source.xlsx"),
-                target_path=str(self.temp_dir / "target")  # No extension
+                target_path=str(self.temp_dir / "target"),  # No extension
             )
 
             assert result["success"] is True
@@ -376,12 +378,14 @@ class TestErrorHandling(BaseTestCase):
         """Test handling of Excel to Google Sheets conversion errors."""
         with mock_manager.spreadsheet_scenario() as mocks:
             # Make the source spreadsheet fail
-            mocks["source"].__enter__.side_effect = Exception("Excel file not found: /tmp/test.xlsx")
+            mocks["source"].__enter__.side_effect = Exception(
+                "Excel file not found: /tmp/test.xlsx"
+            )
 
             result = convert_excel_to_google_sheets(
                 excel_file_path="/tmp/test.xlsx",
                 google_sheets_url="https://docs.google.com/spreadsheets/d/target123/edit",
-                auth_credentials={"auth_secret": self.encoded_creds}
+                auth_credentials={"auth_secret": self.encoded_creds},
             )
 
             assert result["success"] is False
@@ -393,7 +397,7 @@ class TestErrorHandling(BaseTestCase):
         result = convert_spreadsheet_format(
             source=str(self.temp_dir / "input.xlsx"),
             target=str(self.temp_dir / "output.xlsx"),
-            auth_credentials={"auth_secret": self.encoded_creds}
+            auth_credentials={"auth_secret": self.encoded_creds},
         )
 
         # Should fail due to missing file
