@@ -79,6 +79,29 @@ class TestUrlAndRangeParsing:
         result = split_segments("A1||B2||C3", sep="||")
         assert result == ["A1", "B2", "C3"]
 
+    def test_separator_configuration(self):
+        """Test configuring the global separator."""
+        from urarovite.utils.sheets import get_segment_separator, set_segment_separator
+
+        # Test default separator
+        assert get_segment_separator() == "@@"
+
+        # Test setting new separator
+        set_segment_separator(",")
+        assert get_segment_separator() == ","
+
+        # Test that split_segments uses the new separator by default
+        result = split_segments("A1,B2,C3")
+        assert result == ["A1", "B2", "C3"]
+
+        # Test that explicit separator still works
+        result = split_segments("A1@@B2@@C3", sep="@@")
+        assert result == ["A1", "B2", "C3"]
+
+        # Restore default separator
+        set_segment_separator("@@")
+        assert get_segment_separator() == "@@"
+
     def test_strip_outer_single_quotes(self):
         """Test removing outer single quotes."""
         test_cases = [
@@ -194,7 +217,7 @@ class TestFetchSheetTabs:
         mock_service = Mock()
         mock_spreadsheets = Mock()
         mock_get = Mock()
-        mock_execute = Mock()
+        Mock()
 
         # Set up the mock chain
         mock_service.spreadsheets.return_value = mock_spreadsheets
